@@ -28,7 +28,7 @@ public:
     virtual ResultIterator exec() = 0;
 
     static Query *fromJSON(const QByteArray &json);
-    static QString defaultLocation(const QString &dbName);
+    [[nodiscard]] static QString defaultLocation(const QString &dbName);
 };
 }
 }
